==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/user/messages/vi/account.php <==
<?php

return [
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Xác nhận</strong> địa chỉ email mới của bạn',
    '<strong>Your</strong> profile' => 'Hồ sơ <strong>của bạn</strong>',
    'All your personal data will be irrevocably deleted.' => 'Tất cả dữ liệu cá nhân của bạn sẽ bị xóa vĩnh viễn.',
    'Are you sure that you want to delete your account?' => 'Bạn có chắc muốn xóa tài khoản của mình?',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Thay đổi username (tên truy cập) có thể khiến một số liên kết bị hỏng, VD: Liên kết cũ đến trang hồ sơ cá nhân của bạn sẽ không thể truy cập được nữa.',
    'Confirm' => 'Xác nhận',
    'Current password' => 'Mật khẩu hiện tại',
    'Delete account' => 'Xóa tài khoản',
    'Do you really want to delete your icon image?' => 'Bạn có thực sự muốn xóa hình ảnh biểu tượng của bạn?',
    'Do you really want to delete your logo image?' => 'Bạn thực sự muốn xóa ảnh Logo?',
    'E-Mail' => 'E-Mail',
    'E-Mail change' => 'Thay đổi e-mail',
    'Enter your password to continue' => 'Nhập mật khẩu của bạn để tiếp tục',
    'General' => 'Chung',
    'Hello' => 'Xin chào',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Tại đây bạn có thể chỉnh sửa thông tin cá nhân tổng quát (thông tin xuất hiện ở trang giới thiệu của bạn)',
    'Hide introduction tour panel on dashboard' => 'Ẩn menu hướng dẫn người dùng trên Trang chính',
    'Invalid link! Please make sure that you entered the entire url.' => 'Liên kết không hợp lệ ! Hãy chắc chắn rằng bạn đã nhập đúng địa chỉ url .',
    'Language' => 'Ngôn ngữ',
    'Modules' => 'Modules',
    'New E-Mail address' => 'Địa chỉ E-mail mới',
    'New User name' => 'Tên truy cập mới',
    'Not registered users' => 'Người dùng chưa đăng ký',
    'Notifications' => 'Thông báo',
    'Other users' => 'Người dùng khác',
    'Password Recovery' => 'Khôi phục mật khẩu',
    'Permissions' => 'Quyền truy cập',
    'Profile' => 'Profile',
    'Profile visibility' => 'Hiển thị hồ sơ cá nhân',
    'Registered users only' => 'Chỉ dành cho người đã đăng ký tài khoản',
    'Save' => 'Lưu',
    'Save profile' => 'Lưu thông tin',
    'The entered e-mail address is already in use by another user.' => 'Địa chỉ e -mail này đã được sử dụng bởi người dùng khác .',
    'TimeZone' => 'Múi giờ',
    'Username has been changed' => 'Username đã được thay đổi',
    'Users' => 'Người dùng',
    'Visible for all (also unregistered users)' => 'Hiển thị cho tất cả (bao gồm cả người dùng chưa đăng ký)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Chúng tôi vừa gửi email xác nhận tới địa chỉ email mới của bạn. <br /> Vui lòng làm theo hướng dẫn trong email.',
    'You are currently the owner of following spaces:' => 'Bạn là chủ sở hữu của các diễn đàn sau:',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Bạn vừa yêu cầu đổi địa chỉ e-mail của mình.<br />Địa chỉ E-mail mới là {newemail}.<br /><br />Để xác nhận địa chỉ e-mail mới, vui lòng click nút link dưới đây.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Bạn đã đổi Username thành công. <br /> Username mới của bạn là {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Bạn phải chuyển quyền sở hữu hoặc xóa các diễn đàn này trước khi bạn có thể xóa tài khoản của mình.',
    'Your account cannot be deleted!' => 'Tài khoản của bạn không thể xóa!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Địa chỉ E-mail hiện tại của bạn là <b>{email}</b>. Bạn có thể đổi địa chỉ E-mail ở đây.',
    'Your current password can be changed here.' => 'Mật khẩu hiện tại của bạn có thể đổi ở đây',
    'Your e-mail address has been successfully changed to {email}.' => 'E-mail của bạn đã được đổi thành công sang địa chỉ mới là {email}.',
    'Your friends' => 'Các bạn của bạn',
    'Your password has been successfully changed!' => 'Mật khẩu của bạn đã được đổi thành công!',
    'Your username has been changed' => 'Username của bạn đã được đổi.',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Username của bạn đã được đổi thành công. <br /> Chúng tôi vừa gửi một email tới địa chỉ email của bạn về thông tin tài khoản mới này.',
    '<strong>Account</strong> Settings' => '',
    '<strong>Permissions</strong>' => '',
    '<strong>Your</strong> Account' => '',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => '',
    'Blocked users' => '',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => '',
    'Hide my online status' => '',
    'Markdown Editor Mode' => '',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
    'Plain' => '',
    'Profile Tags' => '',
    'Rich Text' => '',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => '',
    'You cannot use this username.' => '',
    'Your current username is <b>{username}</b>. You can change your current username here.' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/user/messages/vi/account.php <==
<?php

return [
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Xác nhận</strong> địa chỉ email mới của bạn',
    '<strong>Your</strong> profile' => 'Hồ sơ <strong>của bạn</strong>',
    'All your personal data will be irrevocably deleted.' => 'Tất cả dữ liệu cá nhân của bạn sẽ bị xóa vĩnh viễn.',
    'Are you sure that you want to delete your account?' => 'Bạn có chắc muốn xóa tài khoản của mình?',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Thay đổi username (tên truy cập) có thể khiến một số liên kết bị hỏng, VD: Liên kết cũ đến trang hồ sơ cá nhân của bạn sẽ không thể truy cập được nữa.',
    'Confirm' => 'Xác nhận',
    'Current password' => 'Mật khẩu hiện tại',
    'Delete account' => 'Xóa tài khoản',
    'Do you really want to delete your icon image?' => 'Bạn có thực sự muốn xóa hình ảnh biểu tượng của bạn?',
    'Do you really want to delete your logo image?' => 'Bạn thực sự muốn xóa ảnh Logo?',
    'E-Mail' => 'E-Mail',
    'E-Mail change' => 'Thay đổi e-mail',
    'Enter your password to continue' => 'Nhập mật khẩu của bạn để tiếp tục',
    'General' => 'Chung',
    'Hello' => 'Xin chào',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Tại đây bạn có thể chỉnh sửa thông tin cá nhân tổng quát (thông tin xuất hiện ở trang giới thiệu của bạn)',
    'Hide introduction tour panel on dashboard' => 'Ẩn menu hướng dẫn người dùng trên Trang chính',
    'Invalid link! Please make sure that you entered the entire url.' => 'Liên kết không hợp lệ ! Hãy chắc chắn rằng bạn đã nhập đúng địa chỉ url .',
    'Language' => 'Ngôn ngữ',
    'Modules' => 'Modules',
    'New E-Mail address' => 'Địa chỉ E-mail mới',
    'New User name' => 'Tên truy cập mới',
    'Not registered users' => 'Người dùng chưa đăng ký',
    'Notifications' => 'Thông báo',
    'Other users' => 'Người dùng khác',
    'Password Recovery' => 'Khôi phục mật khẩu',
    'Permissions' => 'Quyền truy cập',
    'Profile' => 'Profile',
    'Profile visibility' => 'Hiển thị hồ sơ cá nhân',
    'Registered users only' => 'Chỉ dành cho người đã đăng ký tài khoản',
    'Save' => 'Lưu',
    'Save profile' => 'Lưu thông tin',
    'The entered e-mail address is already in use by another user.' => 'Địa chỉ e -mail này đã được sử dụng bởi người dùng khác .',
    'TimeZone' => 'Múi giờ',
    'Username has been changed' => 'Username đã được thay đổi',
    'Users' => 'Người dùng',
    'Visible for all (also unregistered users)' => 'Hiển thị cho tất cả (bao gồm cả người dùng chưa đăng ký)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Chúng tôi vừa gửi email xác nhận tới địa chỉ email mới của bạn. <br /> Vui lòng làm theo hướng dẫn trong email.',
    'You are currently the owner of following spaces:' => 'Bạn là chủ sở hữu của các diễn đàn sau:',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Bạn vừa yêu cầu đổi địa chỉ e-mail của mình.<br />Địa chỉ E-mail mới là {newemail}.<br /><br />Để xác nhận địa chỉ e-mail mới, vui lòng click nút link dưới đây.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Bạn đã đổi Username thành công. <br /> Username mới của bạn là {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Bạn phải chuyển quyền sở hữu hoặc xóa các diễn đàn này trước khi bạn có thể xóa tài khoản của mình.',
    'Your account cannot be deleted!' => 'Tài khoản của bạn không thể xóa!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Địa chỉ E-mail hiện tại của bạn là <b>{email}</b>. Bạn có thể đổi địa chỉ E-mail ở đây.',
    'Your current password can be changed here.' => 'Mật khẩu hiện tại của bạn có thể đổi ở đây',
    'Your e-mail address has been successfully changed to {email}.' => 'E-mail của bạn đã được đổi thành công sang địa chỉ mới là {email}.',
    'Your friends' => 'Các bạn của bạn',
    'Your password has been successfully changed!' => 'Mật khẩu của bạn đã được đổi thành công!',
    'Your username has been changed' => 'Username của bạn đã được đổi.',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Username của bạn đã được đổi thành công. <br /> Chúng tôi vừa gửi một email tới địa chỉ email của bạn về thông tin tài khoản mới này.',
    '<strong>Account</strong> Settings' => '',
    '<strong>Permissions</strong>' => '',
    '<strong>Your</strong> Account' => '',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => '',
    'Blocked users' => '',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => '',
    'Do you really want to delete your login background image?' => '',
    'Do you really want to delete your mail header image?' => '',
    'Hide my online status' => '',
    'Markdown Editor Mode' => '',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
    'Plain' => '',
    'Profile Tags' => '',
    'Rich Text' => '',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => '',
    'You cannot use this username.' => '',
    'Your current username is <b>{username}</b>. You can change your current username here.' => '',
];
